@@ -6,12 +6,18 @@ pub type ApiResult<T> = std::result::Result<T, crate::error::ApiError>;
 #[derive(Debug)]
 pub enum ApiError {
     Network(reqwest::Error),
-    Remote(String),
+    Remote(Option<i64>, Option<String>),
+    Join(tokio::task::JoinError),
+    General(String),
 }
 
 impl ApiError {
-    pub fn remote_err<T: ToString>(msg: T) -> Self {
-        Self::Remote(msg.to_string())
+    pub fn remote_err(code: Option<i64>, msg: Option<&str>) -> Self {
+        Self::Remote(code, msg.map(str::to_string))
+    }
+
+    pub fn general<T: ToString>(msg: T) -> Self {
+        Self::General(msg.to_string())
     }
 
     pub fn is_network(&self) -> bool {
@@ -32,11 +38,19 @@ impl From<reqwest::Error> for ApiError {
     }
 }
 
+impl From<tokio::task::JoinError> for ApiError {
+    fn from(error: tokio::task::JoinError) -> Self {
+        Self::Join(error)
+    }
+}
+
 impl fmt::Display for ApiError {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> Result<(), fmt::Error> {
         match self {
             Self::Network(e) => e.fmt(f),
-            Self::Remote(s) => write!(f, "Remote: {}", &s),
+            Self::Join(e) => e.fmt(f),
+            Self::Remote(c, s) => write!(f, "Remote api error code {:?}: {:?}", c, s),
+            Self::General(s) => write!(f, "{}", s),
         }
     }
 }
@@ -45,6 +59,7 @@ impl StdError for ApiError {
     fn source(&self) -> Option<&(dyn StdError + 'static)> {
         match self {
             Self::Network(e) => e.source(),
+            Self::Join(e) => e.source(),
             _ => None,
         }
     }
